
# Make sure you have upgraded version of pip
Windows
```
py -m pip install --upgrade pip
```

Linux/MAC OS
```
python3 -m pip install --upgrade pip
```
## b1 - baka1 Encryption and Decryption Algorithm

```
It's just a side project

```